@@ -17,12 +17,14 @@ class Fan(Device):
     # pylint: disable=too-many-instance-attributes
     # pylint: disable=too-many-public-methods
 
-    def __init__(self,
-                 xknx,
-                 name,
-                 group_address_speed=None,
-                 group_address_speed_state=None,
-                 device_updated_cb=None):
+    def __init__(
+        self,
+        xknx,
+        name,
+        group_address_speed=None,
+        group_address_speed_state=None,
+        device_updated_cb=None,
+    ):
         """Initialize fan class."""
         # pylint: disable=too-many-arguments
         Device.__init__(self, xknx, name, device_updated_cb)
@@ -35,7 +37,8 @@ class Fan(Device):
             feature_name="Speed",
             after_update_cb=self.after_update,
             range_from=0,
-            range_to=100)
+            range_to=100,
+        )
 
     def _iter_remote_values(self):
         """Iterate the devices RemoteValue classes."""
@@ -44,24 +47,21 @@ class Fan(Device):
     @classmethod
     def from_config(cls, xknx, name, config):
         """Initialize object from configuration structure."""
-        group_address_speed = \
-            config.get('group_address_speed')
-        group_address_speed_state = \
-            config.get('group_address_speed_state')
+        group_address_speed = config.get("group_address_speed")
+        group_address_speed_state = config.get("group_address_speed_state")
 
         return cls(
             xknx,
             name,
             group_address_speed=group_address_speed,
-            group_address_speed_state=group_address_speed_state)
+            group_address_speed_state=group_address_speed_state,
+        )
 
     def __str__(self):
         """Return object as readable string."""
-        return '<Fan name="{0}" ' \
-            'speed="{1}" />' \
-            .format(
-                self.name,
-                self.speed.group_addr_str())
+        return '<Fan name="{}" ' 'speed="{}" />'.format(
+            self.name, self.speed.group_addr_str()
+        )
 
     async def set_speed(self, speed):
         """Set the fan to a desginated speed."""
@@ -72,7 +72,9 @@ class Fan(Device):
         if action.startswith("speed:"):
             await self.set_speed(int(action[6:]))
         else:
-            self.xknx.logger.warning("Could not understand action %s for device %s", action, self.get_name())
+            self.xknx.logger.warning(
+                "Could not understand action %s for device %s", action, self.get_name()
+            )
 
     async def process_group_write(self, telegram):
         """Process incoming GROUP WRITE telegram."""
