@@ -36,9 +36,9 @@ class DPT2ByteUnsigned(DPTBase):
             knx_value = int(value)
             if not cls._test_boundaries(knx_value):
                 raise ValueError
-            return knx_value >> 8, knx_value & 0xff
+            return knx_value >> 8, knx_value & 0xFF
         except ValueError:
-            raise ConversionError("Cant serialize %s" % cls.__name__, value=value)
+            raise ConversionError("Could not serialize %s" % cls.__name__, value=value)
 
     @classmethod
     def _test_boundaries(cls, value):
