@@ -21,7 +21,7 @@ class DPTString(DPTBase):
     def from_knx(cls, raw):
         """Parse/deserialize from KNX/IP raw data."""
         cls.test_bytesarray(raw)
-        value = str()
+        value = ""
         for byte in raw:
             if byte != 0x00:
                 value += chr(byte)
@@ -40,7 +40,7 @@ class DPTString(DPTBase):
             raw.extend([0] * (cls.payload_length - len(raw)))
             return raw
         except ValueError:
-            raise ConversionError("Cant serialize %s" % cls.__name__, value=value)
+            raise ConversionError("Could not serialize %s" % cls.__name__, value=value)
 
     @classmethod
     def _test_boundaries(cls, value):
