@@ -1,6 +1,5 @@
 """Abstraction to send ConnectonStateRequest and wait for ConnectionStateResponse."""
-from xknx.knxip import (
-    HPAI, ConnectionStateResponse, KNXIPFrame, KNXIPServiceType)
+from xknx.knxip import HPAI, ConnectionStateResponse, KNXIPFrame, KNXIPServiceType
 
 from .request_response import RequestResponse
 
@@ -19,9 +18,7 @@ class ConnectionState(RequestResponse):
         (local_addr, local_port) = self.udpclient.getsockname()
         knxipframe = KNXIPFrame(self.xknx)
         knxipframe.init(KNXIPServiceType.CONNECTIONSTATE_REQUEST)
-        knxipframe.body.communication_channel_id = \
-            self.communication_channel_id
-        knxipframe.body.control_endpoint = HPAI(
-            ip_addr=local_addr, port=local_port)
+        knxipframe.body.communication_channel_id = self.communication_channel_id
+        knxipframe.body.control_endpoint = HPAI(ip_addr=local_addr, port=local_port)
 
         return knxipframe
