@@ -1,4 +1,4 @@
 """KNX Constants used within  io."""
 
-DEFAULT_MCAST_GRP = '224.0.23.12'
+DEFAULT_MCAST_GRP = "224.0.23.12"
 DEFAULT_MCAST_PORT = 3671
