@@ -1,7 +1,7 @@
 """Basis class for all KNX/IP bodies."""
 
 
-class KNXIPBody():
+class KNXIPBody:
     """Basis class for all KNX/IP bodies."""
 
     def __init__(self, xknx):
@@ -10,16 +10,22 @@ class KNXIPBody():
 
     def calculated_length(self):
         """Get length of KNX/IP body."""
-        self.xknx.logger.warning("calculated_length not implemented for %s", self.__class__.__name__)
+        self.xknx.logger.warning(
+            "'calculated_length()' not implemented for %s", self.__class__.__name__
+        )
 
     def from_knx(self, raw):
         """Parse/deserialize from KNX/IP raw data."""
         # pylint: disable=unused-argument
-        self.xknx.logger.warning("from_knx not implemented for %s", self.__class__.__name__)
+        self.xknx.logger.warning(
+            "'from_knx()' not implemented for %s", self.__class__.__name__
+        )
 
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
-        self.xknx.logger.warning("to_knx not implemented for %s", self.__class__.__name__)
+        self.xknx.logger.warning(
+            "'to_knx()' not implemented for %s", self.__class__.__name__
+        )
 
     def __eq__(self, other):
         """Equal operator."""
