@@ -13,8 +13,10 @@ class RemoteValueString(RemoteValue):
 
     def payload_valid(self, payload):
         """Test if telegram payload may be parsed."""
-        return (isinstance(payload, DPTArray)
-                and len(payload.value) == DPTString.payload_length)
+        return (
+            isinstance(payload, DPTArray)
+            and len(payload.value) == DPTString.payload_length
+        )
 
     def to_knx(self, value):
         """Convert value to payload."""
